==> qtjambi-uic-5.15.18-sources.jar: io/qt/uic/ui4/DomInclude.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * @hidden
 * <p>Java wrapper for Qt class <code>DomInclude</code></p>
 */
public class DomInclude extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>DomInclude::<wbr/>DomInclude()</code></p>
     */
    public DomInclude(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomInclude instance);
    
    /**
     * <p>See <code>DomInclude::<wbr/>attributeImpldecl()const</code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String attributeImpldecl(){
        return attributeImpldecl_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String attributeImpldecl_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomInclude::<wbr/>attributeLocation()const</code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String attributeLocation(){
        return attributeLocation_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String attributeLocation_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomInclude::<wbr/>clearAttributeImpldecl()</code></p>
     */
    @QtUninvokable
    public final void clearAttributeImpldecl(){
        clearAttributeImpldecl_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearAttributeImpldecl_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomInclude::<wbr/>clearAttributeLocation()</code></p>
     */
    @QtUninvokable
    public final void clearAttributeLocation(){
        clearAttributeLocation_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearAttributeLocation_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomInclude::<wbr/>hasAttributeImpldecl()const</code></p>
     */
    @QtUninvokable
    public final boolean hasAttributeImpldecl(){
        return hasAttributeImpldecl_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasAttributeImpldecl_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomInclude::<wbr/>hasAttributeLocation()const</code></p>
     */
    @QtUninvokable
    public final boolean hasAttributeLocation(){
        return hasAttributeLocation_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasAttributeLocation_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomInclude::<wbr/>read(QXmlStreamReader&amp;)</code></p>
     */
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    /**
     * <p>See <code>DomInclude::<wbr/>setAttributeImpldecl(QString)</code></p>
     */
    @QtUninvokable
    public final void setAttributeImpldecl(java.lang.@NonNull String a){
        setAttributeImpldecl_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setAttributeImpldecl_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    /**
     * <p>See <code>DomInclude::<wbr/>setAttributeLocation(QString)</code></p>
     */
    @QtUninvokable
    public final void setAttributeLocation(java.lang.@NonNull String a){
        setAttributeLocation_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setAttributeLocation_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    /**
     * <p>See <code>DomInclude::<wbr/>setText(QString)</code></p>
     */
    @QtUninvokable
    public final void setText(java.lang.@NonNull String s){
        setText_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), s);
    }
    
    @QtUninvokable
    private native void setText_native_cref_QString(long __this__nativeId, java.lang.String s);
    
    /**
     * <p>See <code>DomInclude::<wbr/>text()const</code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String text(){
        return text_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String text_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomInclude::<wbr/>write(QXmlStreamWriter&amp;,<wbr/>QString)const</code></p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected DomInclude(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
}

==> qtjambi-uic-6.2.9-sources.jar: io/qt/uic/ui4/DomInclude.java <==
package io.qt.uic.ui4;


/**
 * <p>Java wrapper for Qt class DomInclude</p>
 */
public class DomInclude extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public DomInclude(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomInclude instance);
    
    @io.qt.QtUninvokable
    public final java.lang.String attributeImpldecl(){
        return attributeImpldecl_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String attributeImpldecl_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final java.lang.String attributeLocation(){
        return attributeLocation_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String attributeLocation_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearAttributeImpldecl(){
        clearAttributeImpldecl_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearAttributeImpldecl_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearAttributeLocation(){
        clearAttributeLocation_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearAttributeLocation_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasAttributeImpldecl(){
        return hasAttributeImpldecl_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasAttributeImpldecl_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasAttributeLocation(){
        return hasAttributeLocation_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasAttributeLocation_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void read(io.qt.core.QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @io.qt.QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    @io.qt.QtUninvokable
    public final void setAttributeImpldecl(java.lang.String a){
        setAttributeImpldecl_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setAttributeImpldecl_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    @io.qt.QtUninvokable
    public final void setAttributeLocation(java.lang.String a){
        setAttributeLocation_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setAttributeLocation_native_cref_QString(long __this__nativeId, java.lang.String a);
    
    @io.qt.QtUninvokable
    public final void setText(java.lang.String s){
        setText_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), s);
    }
    
    @io.qt.QtUninvokable
    private native void setText_native_cref_QString(long __this__nativeId, java.lang.String s);
    
    @io.qt.QtUninvokable
    public final java.lang.String text(){
        return text_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String text_native_constfct(long __this__nativeId);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
    
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer, java.lang.String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @io.qt.QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected DomInclude(QPrivateConstructor p) { super(p); } 
    
}
